#delimit ;

program define week3;
version 4.0;
if "`1'"=="" {;
  stepdef 1 "Visualizing Linear Regression";
  stepdef 2 "Linear Regression in Stata";
  stepdef 3 "Properties of OLS Estimates";
  stepdef 4 "List of Computational Properties of OLS";
  exit;
  };
 if "`1'"=="doquiz" {; doquiz; exit; };
 loc t = "step`1'"; `t';
end;

program define step2;
  version 3.0;  set trace off;  cap preserve;
  di _n _col(10)
"Do Chapter 6 pp.73-76 and pp. 79-82 in Statistics with Stata." _n
"and/or run the Stata tutorial on regress (type " in w "tutorial regress" in  y;
di 
"Focus on how to use the basic versions of " in w "regress, predict, and graph. " _n
in b "to do regression analysis. Don't worry about the discussion of hypothesis " _n
"testing and diagnostic measures until next week.";
end;
 
program define step10;
  version 3.0;
  drop _all;
  cap use nations;
  cap use c:/stata/nations;
  cap use c:/stustata/nations;
  cap use d:/stustata/nations;
  if _N < 109 {;
    refresh;
    di in r "I'm sorry.  I can't locate " in w "nations.dta " in r "on this " _n
	    "computer.  I've looked in the following directories: "
	    _n _col(10) in w
	    "c:/stata" _n _col(10)
	    "c:/stustata" _n _col(10)
	    "d:/stustata" _n _col(10)
	    ". (current home directory)" _n;
    inprompt "enter the directory where nations.dta is located (eg. c:/mydata)";
    loc pth = "$junk"+"/nations.dta";
    cap use `pth';
    if _N < 109 {; di in r "Still can't find it - exiting tutorial"; exit; };
    };
end;

program define step1;
  version 3.0;  set trace off;  cap preserve;
  di in y
"We are going to get a feel for linear regression using data from one of" _n
"the sample data sets that comes with Student Stata.  The data are stored" _n
"in a file called " in w "nations.dta. " in y "I will load it for you:"    _n;
  step10;
  set trace on;
  describe;
  set trace off;
  prompt "When ready to see a summary of selected variables";
  descr country birth infmort life;
  summ birth infmort life;
  set trace off;
di in y
"The variable labels give you a lot of information about the data.  We are " _n
"going to focus on two variables: " in w "birth " in y "(births per" _n
"one thousand people in the population) and " in w "infmort " in y "(deaths" _n
"of infants per 1000 births within the first year of life.  What kind of " _n
"relationship would you expect to see between birth rates and infant" _n
"mortality rates?";
inprompt "Positive or negative Relationship (p/n)";
refresh;
di in y
"We will treat infmort as the " in w "independent " in y "variable, assuming that it depends"   _n
"upon the general wealth of the country and is to a large degree out of the"  _n
"hands of individual parents to control.  We will consider the birth rate "   _n
"to be the " in w "explained " in y "variable, because many researchers agree"  _n
"that couples can and do control the number of births." _n(3)
"Let's graph the data, first just as points and then with labels for the" _n
"country.  (Try to find Canada on the second graph.) " _n;
prompt "When ready to graph";
gen str3 ctry = substr(country,1,3);
graph birth infmort;
graph birth infmort, s([ctry]);
refresh;
di in y "Here is the information for Canada (which is hard to see)";
set trace on;
list birth infmort if ctry=="Can";
set trace off;
di in y "What kind of relationship did the graph reveal:"_n
"   -1 negative	  " _n
"    0 no relation " _n
"    1 positive	  " _n;
inprompt "Enter your answer (-1,0,1)";
di in y
"Yes, of course, the upward slope in the graph indicates a positive" _n
"relationship.  Countries with high rates of children dying also have " _n
"have high rates of children being born. Can you think of an ECONOMIC " _n
"REASON why this might be true?" _n;
prompt "When ready to go on";
di in y
"Do you think the relationship between mortality and birth rates is" _n
"    0  LINEAR " _n
"    1  NON-LINEAR or CURVED ";
inprompt "Enter your answer (0,1)";
refresh;
di in y
"Let's see what happens when we transform the variables.  I am going to	" _n
"create new variables that are the natural logarithms of birth and infmort." _n
"Watch:	 " _n;
    cap drop lbirth lmort;
    cap keep birth infmort gnpcap ctry country;
    set trace on;
    gen lbirth = ln(birth);
    gen lmort = ln(infmort);
    label variable lbirth "Natural log of birth rate";
    label variable lmort "Natural log of infant mortality";
    set trace off;
di in g "Note:  these next 3 commands add an observation at lmort=0 so that" _n
	"later graphs will include the X-axis and Y-axis intercept b0";
    set trace on;
    set obs 110;
    replace lmort = 0 if _n==110;
    replace lbirth = . if _n==110;
    set trace off;
    prompt "When ready to see a graph of the data";
    graph lbirth lmort;
di in y "Do you think the relationship in logs was" _n
"    0  LINEAR " _n
"    1  NON-LINEAR or CURVED " _n;
inprompt "Enter your answer (-1,0,1)";
refresh;
di in y
"At least it looks closer to linear than the first graph in levels.  This" _n
"means the assumption that the linear regresion equation is closer to reality" _n
"for the log values rather than the levels.  (Formal testing of the " in w _n
"specification " in y "of the regression model will have to wait.) Since this" _n
"isn't a democracy I say we are going to use the logarithms not levels." _n(2)
"Let's first try the " in w "eye-ball " in y "approach to linear regression. " _n
"We want to estimate the equation"      _n
in w "        lbirth = b0 + b1 * lmort + eps  " _n;
di in y
"In other words, we want to find values of b0 and b1 which best explain the" _n
"relationship between the two variables.  I'll show you the graph again and"_n
"you try to guess numerical values for b0 and b1 (you'll get as many tries as" _n
"you want.  Try to " in w "minimize " in y "the sum of squared residuals " _n
"by choosing b0 and b1" _n;
prompt "When ready to start";
   cap drop lbhat oldgss ehat sq_ehat ssq;
   gen lbhat = .;
   label variable lbhat "Guess Regression";
   gen oldgss = .;
   gen ehat = .;
   gen sq_ehat = .;
   gen ssq = .;
   label variable oldgss "Previous Guess";
   local ssq = 0;
   graph lbirth lmort, s(o) title("Try to guess b0 and b1")
	 xlabel(0,1,2,3,4,5) ylabel(0,1,2,3,4);
   local goon = "Y";
   refresh;
   while "`goon'"=="Y" | "`goon'"=="y" {;
     inprompt "Enter your guess for the intercept b0";
     local b0 = $junk;
     inprompt "Enter your guess for the slope b1";
     local b1 = $junk;
     refresh;
     replace oldgss = lbhat;
     replace lbhat = `b0' + `b1'*lmort;
     replace ehat = lbirth-lbhat;
     replace sq_ehat = ehat*ehat;
     replace ssq = sum(sq_ehat);
     local chssq = round(ssq[_N]-`ssq',.01);
     local ssq = round(ssq[_N],.1);
     graph lbirth lbhat oldgss lmort, c(.ll) s(Opd) sort
	       title("Residual Sum of Squares = `ssq'")
	       xlabel(0,1,2,3,4,5) ylabel(0,1,2,3,4);
     di in y
    "Actual and predicted values for a few countries: ";
    list country lmort lbirth lbhat ehat sq_ehat in 1/10;
    di in w "Your Sample Regression Function:   " _n
    _col(10) "lbhat = `b0' + `b1' * lmort" _n;
    di in y  "Total Residual Sum of Squares = " `ssq' _n
	     "Change from Previous Guess    = " `chssq' _continue;
    if `ssq' > 0 {;
       if `chssq' < 0 {;
	  di in b "  The fit improved" _n; };
       else {;
	  di in b "  The fit got worse" _n; };
       };
    else {; di _n; };
    inprompt "Do you want to try another regression line (y/n)";
    local goon = "$junk";
     };
    di in w "Your Final Sample Regression Function:   " _n
    _col(10) "lbhat = `b0' + `b1' * lmort" _n;
    di in y  "Total Residual Sum of Squares = " `ssq' _n
	     "Change from Previous Guess    = " `chssq';
    di in y "And now the OLS estimates:";
  regress lbirth lmort;
  local olssq = round(_result(4),0.000001);
  di in r "The Residual Sum of Squares from the regression = `olssq'" _n
     in r "Find the RSS in the output table.  What might Total SS be?";
  prompt "When ready to go on";
  di in y "Watch how I create predicted values from the OLS regression";
  cap drop lb_ols;
  set trace on;
  predict lb_ols;
  set trace off;
  label variable lb_ols "OLS Predicted log-birth rate";
  prompt "When ready to see the graph comparing your estimates to OLS";
  graph lbirth lbhat lb_ols lmort, c(.ll) s(Opd) sort
	     title("OLS RSS = `olssq' Eyeball RSS =`ssq'")
	     xlabel(0,1,2,3,4,5) ylabel(0,1,2,3,4);
  di in y "Perhaps the moral of this step is simply:  A little" _n
	  "calculus is better than a lot of guessing when trying " _n
	  "to minimize a function.";
  drop _all;
  end;

program define step4;
version 3.0;  set trace off;
di in y
"Here is a verbal list of Properties of OLS Estimates (Gujarati p. 50-51)"
_n(2) in b
"1.  The regression line passes through the sample means of X and Y" _n
"2.  The mean of predicted Y values equals the mean of sample Y values" _n
"3.  The mean (and sum) of prediction erorrs is zero" _n
"4.  The prediction errors are uncorrelated with the predicted Y values" _n
"5.  The prediction errors are uncorrelated with the sample values of X" _n(2);
end;

program define step3;
  version 3.0;  set trace off;
  di in b _col(10) 
"For the general regression" _n _col(10) in w
"Y = b0 + b1 X + u" _n in y
"The OLS estimates of b0 and b1 were derived in class as" _n _col(10) in w
"                _     _   " _n _col(10)
"hat    n    (Xi-X)(Yi-Y)  " _n _col(10)
"b1 =  SUM   ------------  " _n _col(10)
"      i=1     n      _ 2  " _n _col(10)
"             SUM (Xk-X)   " _n _col(10)
"             k=1          " _n(3) _col(10)
"hat   _   hat _           " _n    _col(10)
"b0  = Y - b1  X           " _n(2) _col(10) in y;
di in y "In this step you are going to use Stata to confirm some of the properties" _n
	"of OLS estimates discussed in class.  We will use the same data set " _n
	"as in step 2, but we will focus on two other variables." _n;
  drop _all;
  step10;
  cap keep country gnpcap energy;
   set trace on;
   describe;
   summ;
   set trace off;
   di in y "In this example we will look at the relationship between energy" _n
	 "consumption and GNP, both in per capita terms." _n;
   di
   "Notice that two countries have missing energy data - I'll drop these." _n
   "Pay attention to the means for the remaining observations:";
   set trace on;
   drop if energy==.;
   summ;
   set trace off;
   prompt "When ready to continue";
   di in y
   "Which makes more sense to use as the X (independent variable)?";
   inprompt "0=gnpcap, 1=energy, enter 0 or 1";
   di in y "I submit (hypothesize) that energy consumption is probably more" _n
"determined by GNP rather than vice versa.  That's because " _n
"energy is an input to aggregate production and consumption, and GNP would help "
"determine per-capita energy demand. But notice that a regression analysis " _n
"can NEVER prove which way the causality goes.  It can only establish" _n
"the existence or non-existence of a RELATIONSHIP. In fact, countries with" _n
"large supplies of energy may be able to afford higher GNP per capita." _n
"Trying to determine which variable causes the other requires more than" _n
"the regression techniques we are studying can deliver.";
   prompt "When ready to see a graph";
   graph energy gnpcap;
   refresh;
   step4;
di in y "Explanations and proofs are provdied in class, in the text, and in" _n
	"Prof. Abbott's notes available at JD Copy Center.";
di in y "Your job is to confirm these results.  I will run the regression," _n
	"compute the predicted values and residuals.  You must use Stata," _n
	"to confirm the properties.";
    set trace on;
    regress energy gnpcap;
    predict enhat;
    predict e, residuals;
    set trace off;
    summ energy gnpcap e enhat;
    di in y "The variables generated and summarized above match up to " _n
	    "are variables defined in class in the following way ";
    di in y "Here I'll show you 2 ways to illustrate property 1." _n
	    "which says that the OLS regression line goes through the " _n
	    "sample means.  The table above provides the sample means " _n
	    "of X (gnpcap) and Y (energy).  One way to show property 1 " _n
	    "is to graph the OLS regression line b0hat + b1hat*X with " _n
	    "the sample means" _n(2);
    prompt "when ready for a graphical illustration";
    graph energy enhat gnpcap, xlabel(3246.7) ylabel(1471.2)
		 xline(3246.7) yline(1471.2)
	  title(1. OLS line passes through sample means);
    refresh;
    di
    "A second way to illustrate property 1 is to compute the predicted " _n
    "value of Y for X = Xbar.  In other words, simply confirm that " _n
    "b0hat + b1hat * Xbar = Ybar. The display makes this easy to do:" _n;
    prompt "when ready for a numerical illustration";
    set trace on;
    summ energy gnpcap;
    display "Y hat at Xbar =  " _coef[_cons]+_coef[gnpcap]*3246.7 " = Ybar ";
    set trace off;
    di
    "Notice that the value of b0hat is stored in _coef[_cons] and b1hat is " _n
    "stored in _coef[gnpcap].  The display command above computed the OLS line" _n
    "above the sample mean of gnpcap and it confirms that it equals the sample " _n
    "mean of energy.  So this illustrates property 1, that the OLS regression line " _n
    "passes through the sample means." _n;
    prompt "when ready to continue";
    refresh;
    step4;
    di
    "The data will remain loaded.  Try to confirm the other properties" _n
    "using " in w "correlate, generate, egen, list, display " in y
    "and other Stata commands." _n(2)
    "To see the list of properties again at any time, just type "
    in w "goto 4";
end;

