#delimit ;

program define week4;
version 4.0;
if "`1'"=="" {;
 stepdef 1 "Objectives of this Tutorial";
 stepdef 2 "Understanding the Stata Regression Output Table";
 stepdef 3 "Making Predictions and Computing Confidence Intervals";
 stepdef 4 "Hypothesis Tests on OLS Regression Coefficeints";
 stepdef 5 "Review of Major Points";
  exit;
  };
 if "`1'"=="doquiz" {; doquiz; exit; };
 loc t = "step`1'"; `t';

end;

program define step9;
  version 3.0;
  drop _all;
  cap use nations;
  cap use c:/stata/nations;
  cap use c:/stustata/nations;
  cap use d:/stustata/nations;
  if _N < 109 {;
    refresh;
    di in r "I'm sorry.  I can't locate " in w "nations.dta " in r "on this " _n
            "computer.  I've looked in the following directories: "
            _n _col(10) in w
            "c:/stata" _n _col(10)
            "c:/stustata" _n _col(10)
            "d:/stustata" _n _col(10)
            ". (current home directory)" _n in r
    "Please place a copy of the file in one of these directories then try" _n
    "this step again" _n(3)
     exit;
    };
end;

program define step1;
  version 3.0;  set trace off;  cap preserve;
  di in y
  "This tutorial teaches you how to use Stata to perform three types " _n
  "of procedures using the OLS regression model.  The procedures are:" _n
 in w
  "1.  How to " in b "predict " in w "the value of Y given a value of X and the OLS estimates" _n
  "2.  How to compute a " in b "confidence intervals " in w "for " in b "predicted " in w "values of Y"_n
  "3.  How to perform " in b "hypothesis tests " in w "for regression coefficients." _n;
di in y
"The tutorial relies heavily on the following commands: " in w _n
"         regress  " _n
"         predict  " _n
"         display  " _n in y
"You should quickly review these commands if you aren't comfortable with them." _n
"You can do this by quickly running through tutorial #3 and then returning to " _n
"this tutorial.";
di in r _n 
 "Also:  This tutorial uses both the city.dta and nations.dta data set ";
end;


program define step2;
  version 3.0;  set trace off;  cap preserve;
  di in y
"Let's first review the formulas concerning OLS estimates presented in"_n
"class.  The linear regression model can be written " _n(2) in w
"(*)   Y  =  b1   +  b2X + u" _n(2)
"    A.2 (*) is the true relationship between X and Y" _n
"    A.3 cov(u,X) = 0  (or X's fixed in repeated samples)" _n
"    A.4 E(u|X) = 0 " _n
"    A.5 cov(ui,uj) = 0" _n
"    A.6 var(ui) = s**2   (I'll use s for sigma) " _n
"    --- " _n
"    A.7 ui is normally distributed: ui ~ N(0,s**2)" _n;
prompt "when ready to continue";
refresh;
di "The OLS estimates of b1 and b2 can be written" _n in b
   "   hat           N                   N     xi         " _n
   "   b2        =  SUM  k  Y         = SUM ----------  Y " _n
   "                i=1   i  i          i=1  SUM xi*xi   i" _n
   "                                            " _n
   "   hat           _    hat _"                       _n
   "   b1        =   Y  - b2  X"                       _n;

di in y "We also derived the Variances of these estimators:_n" in b
   "                                                             "  _n
   "    hat      N     s*s                                       "  _n
   "VAR(b2 ) =  SUM  ---------           hat      N   s*s Xi*Xi  "  _n
   "            i=1  SUM xi*xi       VAR(b1 ) =  SUM  ----------  " _n
   "                                             i=1  N SUM xi*xi " _n;
di in y "However, we can't observe s*s, so we have to estimate it:" in b
   "                                 " _n
   "   hat      N   ei * ei     RSS  " _n
   "   s*s  =  SUM  -------  =  ---  " _n
   "                 N - 2      N-2  "_n;
di in y "Recall that RSS stands for Residual Sum of Squares. " _n
   "Replacing s*s with this estimate, and taking square roots we get" _n
   "the " in w "estimated " in y "standard errors:";
prompt "when ready to see formulas for estimated standard errors";
di in b
"           |                | 1/2                                     " _n
"           |        hat     |                  |     hat         | 1/2 " _n
"hat hat    |  N     s*s     |       hat hat    | N   s*s Xi*Xi   |     " _n
"se (b2 ) = | SUM  --------- |       se (b1 ) = |SUM  ----------  |     " _n
"           | i=1  SUM xi*xi |                  |i=1  N SUM xi*xi |     " _n;
di in y "Much better looking versions of these expressions are given in" _n
   "the regression notes" _n;
di "The value of sqrt(hat s*s) is reported in the Stata output as the" _n
   "the Root MSE (square root of the mean square error).  The values"  _n
   "for the (estimated) standard errors are reported next to the "     _n
   "estimates themselves in the table.  We are going to check this now.";
prompt "when ready to continue";
refresh;
step9;
set trace on;
keep country school2 urban;
keep if school2 !=. & urban != .;
describe;
summ;
set trace off;
di
"I have loaded the nations data again, and kept the variables summarized" _n
"above.  (Countries with missing information have been dropped already.)" _n
"First we'll graph and then regress rates of high school attendance" _n
"on percentage of population living in urban areas." _n;
prompt "when ready to go on";
set trace on;
graph school2 urban;
regress school2 urban;
set trace off;
di _n "Notice that Stata reports the parameter estimates and the " in w _n
      "estimated standard errors " in y "of the OLS estimates.  How do you think" _n
      "the " in w "t ratio " in y "relates to the estimates and standard errors?" _n
      "How do you think the " in w "confidence interval " in y "is computed?";
prompt "When ready to go on";
di in y
"We also wrote down a formula for " in w "cov(b1hat,b2hat). "  in y "We haven't" _n
"derived the formula yet, but will later.  The formula is given on p. 62 " _n
"in Gujarati.  To get the estimated covariance of the estimates, you can type" _n
"this after running a regression:";
set trace on;
correlate , _coef covariance;
set trace off;
di "Type " in w "help correlate " in y "for more information on that command." _n
   "Notice that the covariance table also provides the " in w "variances " in y _n
   "of the estimates, which are simply the squares of the standard errors.  (Check " _n
   "if you don't believe me.) You should " in w "copy down the correlate command" _n in y
   "as written above, because you will find it useful later on.";
prompt "when ready to go on";
refresh;
di "Now I'll use predict and egen to compute RSS and SUM xi*xi directly.";
regress;
set trace on;
predict ehat, residuals;
set trace off;
qui summ urban;
local mns = _result(3);
di in b "-egen rss = sum(ehat*ehat)" _n
        "-egen sxsq = sum((urban-`mns')*(urban-`mns'))";
egen rss = sum(ehat*ehat);
egen sxsq = sum((urban-`mns')*(urban-`mns'));
set trace on;
summ rss sxsq;
set trace off;
di in y
"Notice that " in w "sxsq " in y "contains " in w "SUM xi * xi " _n in y
"and that " in w "rss " in y "contains " in w "hat sigma." in y _n;
prompt "when ready to continue";
di "Use the " in w "display " in y "command to confirm that Stata is using" _n
"the correct formulas to compute RSS and the standard errors of b1hat and b2hat." _n
"Remember, the standard error is just the square root of the variance, and" _n
in w "display " in y "can take square roots and other operations. The data" _n
"will be kept loaded after this step ends.  Simply type " in w "regress " _n
in y "to see the regression table again.  Also, try to figure what formula is"_n
"used to calculate other numbers in the regression tables.";
end;

program define step13;
  version 3.0;
  drop _all;
  cap use city;
  cap use c:/stata/city;
  cap use c:/stustata/city;
  cap use d:/stustata/city;
  if _N < 109 {;
    refresh;
    di in r "I'm sorry.  I can't locate " in w "city.dta " in r "on this " _n
            "computer.  I've looked in the following directories: "
            _n _col(10) in w
            "c:/stata" _n _col(10)
            "c:/stustata" _n _col(10)
            "d:/stustata" _n _col(10)
            ". (current home directory)" _n in r
    "Please place a copy of the file in one of these directories then try" _n
    "this step again" _n(3)
     exit;
    };
end;

program define step3;
  version 3.0;  set trace off;  cap preserve;
  di in y
  "Making a prediction about Y from OLS is easy:  just calculate the " _n
  "value of the sample regression above the value of X that you want " _n
  "to predict for.  You have also seen that Stata will do this for you" _n
  "if you use the " in w "predict " in y "command.  The harder part " _n
  "is to also report how precise your prediciton is.  The accepted way" _n
  "to do this is by reporting a " in w "confidence interval " in y "for your" _n
  "prediction (or any other population parameter that you are estimating)";
di in y
  "We derived the variance of the OLS prediction in class, and we noted" _n
  "that there are two types of prediction: " in w "mean and individual ." in y "The " _n
  "difference matters in only how precise the prediction is.  The " in w "predict" in y _n
  "command will compute the " in w "standard errors " in y "of predicted values" _n
  "for you, both mean and individual.  Remember, the standard error of a estimate" _n
  "or a prediction is simply the square root of the variance of the estimate " _n
  "or the prediction." _n;
  di in y
  "First, however, we must see how to obtain out-of-sample predictions in Stata." _n
  "Then we will compute the variance directly, and then show how to use predict " _n
  "to do it for us.";
  prompt "When ready to continue";
  refresh;
  step13;
  describe ;
  sort victims;
  di in b "Cities with lowest murder rates per 100K people (1980-84):";
  list city victims poor in 1/5;
  di in b "Cities with highest murder rates:";
  list city victims poor in 141/146;
  di _n in y "We are going to use the " in w "city data set " in y "which has just " _n
     "been loaded.  Let's graph the murder rate against the poverty rate in U.S." _n
     "cities.  We will do it in levels and then logs. ";
  prompt "when ready";
  sort poor;
  graph victims poor, title(Crime Rates and Poverty Rates) ;
  graph victims poor, xlog ylog title("Crime Rates and Poverty Rates (log scales)");
  refresh;
  di "We are going to run a regression in logs rather than levels: ";
  set trace on;
  keep poor victims;
  gen lvict = ln(victims);
  gen lpoor = ln(poor);
  regress lvict lpoor;
  set trace off;
  di _n in y
"One way to compute an out-of-sample prediction is the " in w "display " _n
in y "command.  Suppose you want to predict the murder rate for a city " _n
"with all poor people.  Then the value of X we want to predict for is ln(100) " _n;
 prompt "when ready to continue";
set trace on;
di in w _column(15) "Predicted value = " _b[_cons] + _b[lpoor] * ln(100);
set trace off;
 more;
 di in y
" The values of b1hat and b2hat are stored in _b[_cons] and _b[lpoor] " _n
"after the regression was run with the regress command.  The display command " _n
"in blue computes b1hat + b2hat * ln(100). ";
 more;
 di "Also notice that the prediction is in the same units as the regression." _n
    "The prediction is the " in w "log murder rate" in y ".  If we want to predict" _n
    "in levels we must transform the predicted value to the correct units" _n
    "by reversing the log transformation:" _n;
 set trace on;
 di _column(15) in w "Prediction in levels = " exp(_b[_cons] + _b[lpoor]*ln(100));
 set trace off;
 local px = _b[_cons] + _b[lpoor]*ln(100);
 local tx = exp(_b[_cons] + _b[lpoor]*ln(100));
 di _n(2) "Provide an interpretation for the value " `tx' " in terms of murders";
 prompt "When ready to see the correct interpretation";
 di "The correct interpretation is that the OLS regression predicts that a city" _n
    "that is 100% poor will have " `tx' " murders for every 100,000 people within " _n
    "five years.  (The data are homicides over the five-year period 1980-84.).  Here" _n
    "is a graph of this interpretation (in levels):";
 prompt "when ready to see graph";
 qui predict lvhat;
 qui gen vhat = exp(lvhat);
 qui set obs 147;
 local px = _b[_cons] + _b[lpoor]*ln(100);
 qui replace lvhat = `px' if _n==147;
 qui replace lpoor = ln(100) if _n==147;
 qui replace poor = 100 if _n==147;
 qui replace vhat = `tx' if _n==147;
 graph victim vhat poor, c(.l) xlabel(100) ylabel(`tx') yline(`tx') xline(100)
                         title("Predicting way out of sample");
 refresh;
 di in y
 "Try it yourself.  Use _b[_cons], _b[lpoor], and ln() to:" ;
 ansent "_b[_cons]+_b[lpoor]*ln(50)"  "Predict log murder rate for cities half poor?";
 di "If you didn't get it right, here is what you should have typed:" _n
    in w _col(10) "_b[_cons]+_b[lpoor]*ln(50)" _n
    in y
"The display command will evaluate that expression for you, which is " _n
"equivalent to " _n
"       hat    hat " _n
"        b1 +  b2 * ln(50)";
prompt "when ready to continue";
refresh;
 di in y
 "Another way to predict out-of-sample is to use " in w "input " in y _n
 "to add new observations to the data set that contains the values of the " _n
 "X that you want to predict for.  Make to sure to set the dependent variable Y" _n
 "for the new obs to missing (.). That way if you re-run the regression after" _n
 "entering the values, the new out-of-sample predictions won't be included in " _n
 "in the regression. To make the prediction, simply use the " in w "predict " in y _n
 "command as usual, and list the predicted value for the new observations." _n
 "Stata will compute the predicted value for observations that have missing " _n
 "Y values"_n;
 prompt "when ready to continue";
 refresh;
 di "To compute the standard error for the prediction (let's say mean), note " _n
    " the following " _n in w
_col(10)         "                                      _     _  " _n
_col(10)         "     hat                           (X-X)*(X-X) " _n
_col(10)         " Var( Y | X) = sigma*sigma*( 1/N + ----------- )" _n
_col(10)         "                                   SUM xi * xi " _n(2)
_col(10)         "                                      _     _     hat   " _n
_col(10)         "             = sigma*sigma*(1/N) + (X-X)*(X-X)Var(b2)   " _n(2);

di in y "If you don't see why, remember that variance of b2hat is sigma*sigma/(SUM xi*xi) ";
di in y
"This formula means you can compute the standard error of the prediction " _n
"with the following " in w "5 pieces of information:" _n;
prompt "when ready to see the list";
refresh;
di in y
"Information Needed to Compute Confidence Intervals for Predictions By Hand" _n(2);
di
in w "   1.  value of X to predict for (here ln(100))" _n
     "   2.  estimate of sigma squared (reported as Mean Squared Error, here .26183) " _n
     "   3.  sample size (reported in table, here 146)" _n
     "   4.  mean of X (gotten from summary command)" _n
     "   5.  variance of b2hat (square of std. error of b2hat, here .086486)" _n;
prompt "when ready to see how";
regress;
summ lpoor;
di in b "-di `"'Estimated Standard error of Mean Prediction:`"' " _n
"sqrt(.261826278/146 + (ln(100)-2.3039755)*(ln(100)-2.3039755)*.086486*.086486)";
di "Estimated Standard error of Mean Prediction: " _n _col(10)
sqrt(.261826278/146 + (ln(100)-2.3039755)*(ln(100)-2.3039755)*.086486*.086486);
di "Do you see where each of the numbers comes from?";
more;
set trace on;
local px = _b[_cons] + _b[lpoor]*ln(100);
local sd = sqrt(.262/146 + (ln(100)-2.304)*(ln(100)-2.304)*.086*.086);
set trace off;
di in y
"The two " in w "local " in y "commands store values to use later. In px" _n
"I've stored the predicted value.  In sd I've stored the est. standard error";
prompt "when ready to go on";
di "To compute the confidence interval, you need the following info: " _n in w
"  1.  predicted value itself (in this case `px')" _n
"  2.  critical t value for degrees of freedom and confidence level" _n
"  3.  estimated standard error of the prediction, here " %6.5f `sd' _n;
di in y "Using the values we just computed and the invt function:";
di in b "Compute 90% confidence interval for mean prediction: " _n;
set trace on;
di in w _col(10) "lower bound = "  `px'-invt(144,0.9)*`sd' _n;
di in w _col(10) "upper bound = "  `px'+invt(144,0.9)*`sd' _n;
set trace off;
local lb = `px'-invt(144,0.9)*`sd';
local ub = `px'+invt(144,0.9)*`sd';
di "The values in the local variables sd and px were inserted by Stata. You have to" _n
   "put a left and right quote around the name of a local to retrieve its value" _n;
prompt "when ready to see a graph (in logs)";
local xx = ln(100);
graph lvict lvhat lpoor, c(.l) yline(`lb',`ub') ylabel(`px') xlabel(`xx')
      title("Confidence Interval for Mean Prediction: X=ln(100)");
di
"Can we predict the murder rate for completely poor cities very accurately?" _n
"How wide is the confidence interval in " in w "levels?";
prompt "when ready to continue";
refresh;
di "You have now seen how to use Stata to use OLS estimates to predict" _n
   "values of Y and estimated standard errors of the prediction. " _n
   "It is important that you be able to perform these calculations so that " _n
   "the formulas are real to you, not just a bunch of symbols.  However," _n
   "Stata makes it easier than this to compute confidence intervals:  "_n;
di in b " Re-read pages 75-78 to learn how to use " _n
in w "predict " in b "to automatically compute and store estimated standard errors for both " _n
in w "mean " in b " and " in w "individual " in b "predictions. Stata" _n
     "knows the difference between the two types of prediction. It calls an " _n
     "individual prediction a " in w "forecast."  in y " and a mean prediction" _n
     "simply a " in w "prediction" _n;
drop _all;
end;

program define step8;
 version 3.0; set trace off;
di _n in w
_col(10)    "Model:   Y = b1 + b2 X + u " _n(2)
_col(10)    "  H :   b`5' = " in b `1'  in w _n
_col(10)    "   0             " _n
_col(10)    "  H :   b`5' `2' " in b `1'  _n in w
_col(10)    "   A             " _n(2)
_col(10)    "                      hat         " _n
_col(10)    "                      b`5'   -  `1'  " _n
_col(10)    "Test statistic:  t =  ------------ "_n
_col(10)    "                      hat   hat    "_n
_col(10)    "                      se  ( b`5'  )  "_n(2)
_col(10)    "Distn of test " _n
_col(10)    " statistic under H0: " in b " t with `4' of freedom" in w;
if "`6'"=="|t|" {;
   di in w _col(10)    "Significance level:  " in b 1-`3' ; };
else {;
   di in w _col(10)    "Significance level:  " in b (1-`3')/2 ; };
di
_col(10) in w  "Critical Region:  " in b " reject H0 if `6' > " invt(`4',`3');
if "`7'"!="" {;
di in w
_col(10) "Computed Value of the t in sample:  " in b `7' in w _n
_col(10) "Decision :  " in b _c;
if "`6'"=="t" {;
   if `7' > invt(`4',`3') {; di in b "Reject H0"; };
   else                   {; di in b "Fail to reject H0";};
   };
if "`6'"=="-t" {;
   if -`7' > invt(`4',`3') {; di in b "Reject H0"; };
   else                   {; di in b "Fail to reject H0";};
   };
if "`6'"=="|t|" {;
   if abs(`7') > invt(`4',`3') {; di in b "Reject H0"; };
   else                   {; di in b "Fail to reject H0";};
   };
};

end;

program define step4;
 version 3.0; set trace off;
  di in y
  "Testing hypotheses and computing confidence intervals are two examples " _n
  "of " in w  "statistical inference. " in y "In each case we are using "_n
  "sample information to infer something about a population parameter." _n
  "Recall the problem that a " in w "confidence interval" in y " solves: " _n;
  di in b
  "    Calculate an interval that contains the true parameter of interest" _n
  "    in a pre-determined percentage of possible samples from the population"_n;
  di in y
  "A " in w "hypothesis test " in y " solves a different problem:" _n(2)
  in b
  "    Make a decision to either REJECT or FAIL-TO-REJECT a   " _n
  "    hypothesis that a population parameter equals a particular value." _n
  "    Do this while setting the proportion of samples in which rejection" _n
  "    occurs when the hypothesis is true to a pre-determined value. " _n;
  di in y
  "The proportion of samples in which FALSE rejection occurs is called the" _n
  in w "level of significance of the test." in y " We also call this the " _n
  "probability of a Type I error.  A Type II error is failing to reject the "_n
  "hypothesis when it is actually false."  _n;
  di in y
  "When constructing a confidence interval, the interval depends on the " _n
  "sample and so it is random.  When conducting a hypothesis test, the " _n
  "decision (reject or fail-to-reject) depends on the sample and so it " _n
  "is random before the sample is drawn.  " _n
  "To conduct a hypothesis test, the following information " _n
  "is needed ";
  prompt "when ready to go on";
  refresh;
  di in y "Required Elements of a Hypothesis Test";
  di in w
  "    1.  The NULL Hypothesis H , which states the value to test." _n
  "                             0" _n
  "    2.  The ALTERNATIVE Hypothesis H , which are the values to test against" _n
  "                                    A " _n
  "    3.  The probability of Type I error, usually called ALPHA" _n
  "    4.  A test statistic which can be computed with sample information " _n
  "        and whose distribution is known when the NULL hypothesis is true";
  di in w
  "    5.  The values of the test statistic for which the NULL is rejected " _n
  "        in favour of the ALTERNATIVE. This is sometimes called the CRITICAL " _n
  "        REGION of the test. " _n;
  di in y "Each of these required elements can be determined before " _n
          "anything is done with the sample information.  Once each of "_n
          "these elements is specified correctly, carrying out a hypothesis " _n
          "test is simple.  There are three steps:";
  prompt " when ready to go on";
 di in y _n "3 Steps to carry out a Hypothesis Test";
  di in w
  "    1.  Specify the 5 required elements of a Hypothesis test listed above" _n
  "    2.  Using the sample data, compute the value of the test statistic" _n
  "    3.  Reject the NULL hypothesis if the test statistic falls in " _n
  "        the critical region.  Fail to reject the NULL if the test " _n
  "        statistic does not fall in the critical region" _n;
  prompt "when ready to go through the mechanics of hypothesis tests";
  di in y
  "As with confidence intervals, there are three ways to do hypothesis" _n
  "testing:  " in w "pencil (by hand), display, and test."  in y " I'll return to " _n
  "the city data set used in step 2 and run the same regression before ";
  prompt "when ready to go on";
  step13;
  set trace on;
  keep poor victims;
  gen lvict = ln(victims);
  gen lpoor = ln(poor);
  regress lvict lpoor;
  set trace off;
  local dof = _N-2;
  di in y
  "Now we want to test a specific hypothesis about b2.  In particular:";
  step8 1 ">" 0.9 `dof' 2 "t";
  di in b "Write down the formula for the test statistic above";
  prompt "when ready to continue";
  di in y "Notice that the screen lists the five required elements of " _n
          "a properly specified hypothesis test.  We know the distribution" _n
          "of the test statistic under H0 is the t distribution under "_n
          "assumptions A1-A6 as discussed in class.";
  prompt "when ready to go on";
  regress;
  di in b "Now compute the value of the test statistic by pencil (by hand)";
  prompt "when ready to continue";
  di in y "Here's how to use " in w  "display " in y
  "to compute the value of the test statistic:";
  set trace on;
  di in w _column(15) "Value of t = " (_b[lpoor]-1)/_se[lpoor];
  set trace off;
  di _n(3);
  local tt = (_b[lpoor]-1)/_se[lpoor];
  prompt "when ready to continue";
  di "Notice that _se[lpoor] contains the estimated standard error " _n
     "of b2hat, which you can also read off the regression table" _n
     "The standard error of b1hat is stored in _se[_cons] ";
  prompt "when ready to see a complete summary of test";
  step8 1 ">" .90 `dof' 2 "t" `tt';
  inprompt "Do you want to test another hypothesis (y/n)?";
      local tt = (_b[_cons]+1)/_se[_cons];
      step8 -1 "not equal" .95 `dof' 1 "|t|";
      prompt "when ready to see regression table again";
      regress;
      di in b "Now calculate the test statistic by hand and make decision";
      inprompt "Enter reject or fail";
      set trace on;
      di in w _column(15) "Value of t = " (_b[_cons]+1)/_se[_cons];
      set trace off;
      more;
      step8 -1 "not equal" .95 `dof' 1 "|t|" `tt';
      di in w "Your answer: " in b "$junk" _n;
      more;
      inprompt "Do you want to test two more hypotheses (y/n)?";
      if "$junk"=="y" {;
         di "Here is a two-tailed test concerning b2";
         step8 1.5 "not equal" .90 `dof' 2 "|t|";
         local tt = (_b[lpoor]-1.5)/_se[lpoor];
         prompt "when ready to see regression table again";
         regress;
         di in b "Now calculate the test statistic by hand and make decision";
         inprompt "Enter reject or fail ";
         step8 1.5 "not equal" .90 `dof' 2 "|t|" `tt';
         di in w "Your answer: " in b "$junk" _n;
         more;
         di "Here is a one-tailed test concerning b1";
         step8 -.72 "<" .95 `dof' 1 "|t|";
         local tt = (_b[_cons]-(-.72))/_se[_cons];
         prompt "when ready to see regression table again";
         regress;
         di in b "Now calculate the test statistic by hand and make a decision";
         inprompt "Enter reject or fail";
         step8 0 "<" .95 `dof' 1 "|t|" `tt';
         di in w "Your answer: " in b "$junk" _n;
         more;
      };
  refresh;
  di
"The command " in w "test " in y "will allow you to enter hypotheses and test" _n
"them automatically.  However, it computes an " in w "F-test " in y "rather than" _n
"a t-test, so we have to wait until later to know how to interpret the test." _n;
  di "End of step 4";
  drop _all;
end;

program define step5;
 version 3.0; set trace off;
  di in y
  "You should now know the following points:" _n in w
  "1.  How to use Stata to make predictions based on OLS estimates" _n
  "2.  The 5 pieces of information required to compute confidence intervals "_n
  "    for predicted values of Y." _n
  "3.  The 5 required elements of a hypothesis test and what these elements " _n
  "    are for hypothesis tests of OLS estimates of regression coefficients." _n
  "4.  The 3 steps in carrying out a hypothesis test for a particular sample" _n
  "5.  How to carry out hypothesis tests using Stata.";
 di _n in y
 "If you are unsure of these points, then re-run the steps in the tutorial.";
end;

