#delimit ;

program define week5;
version 4.0;
if "`1'"=="" {;
stepdef 1 "Introduction to Monte Carlo Experiments";
stepdef 2 "Are OLS estimates Unbiased under our Assumptions";
stepdef 3 "Specify and Run your own OLS Monte Carlo Experiment";
stepdef 4 "List of Questions to Answer Using Monte Carlo";
stepdef 5 "Displays the Currently Loaded OLS Monte Carlo Experiment";
  exit;
  };
 if "`1'"=="doquiz" {; doquiz; exit; };
 loc t = "step`1'"; `t';

end;

program define step9;
  version 3.0;
  drop _all;
  cap use nations;
  cap use c:/stata/nations;
  cap use c:/stustata/nations;
  cap use d:/stustata/nations;
  if _N < 109 {;
    refresh;
    di in r "I'm sorry.  I can't locate " in w "nations.dta " in r "on this " _n
	    "computer.  I've looked in the following directories: "
	    _n _col(10) in w
	    "c:/stata" _n _col(10)
	    "c:/stustata" _n _col(10)
	    "d:/stustata" _n _col(10)
	    ". (current home directory)" _n in r
    "Please place a copy of the file in one of these directories then try" _n
    "this step again" _n(3)
     exit;
    };
end;

program define step1;
  version 3.0;  set trace off;  cap preserve;
 macro define true_b1 = 1.5;       * the true value of beta0;
 macro define true_b2 = -0.6;      * the true coefficient on x;
 macro define sigma = 3.0;         * the true st. dev. of the error term;
 macro define smp_size = 15;       * the sample size in each experiment;
 macro define repl = 80;           * the number of experiments to run;
 macro define lowx = -2.0;
 macro define upx = 2.0;
 macro define ucor = 0.0;
 macro define umx = 0.0;
 macro define app = "n";
 macro define expno = 1;
  di _col(10)
  in b "Introduction to Monte Carlo Experiments" _n(2);
  di in w "1." in y
  "In class we showed that Assumptions A.1-A.6 determine the distribution" _n
  "of the OLS estimates.  In particular, we derived the MEAN, the VARIANCE" _n
  "and the COVARIANCE of the OLS estimates under the assumptions A.1-A.5." _n
  "We also showed that the estimates are normally distributed if the " _n
  "disturbance term u is normally distributed (assumption A.6)." _n;
  prompt " to go on ";
  di in w "2." in y
  "While we tried to have some intuition for these results, it is difficult" _n
  "to SEE the distribution of OLS estimates.  The reason why is that for " _n
  "a given sample of data we get one value of the estimate (say beta1 hat)." _n
  "We don't see a distribution unless we take " in w "several " in y "samples from the same" _n
  "population and compute OLS estimates for " in w " each sample." _n;
  prompt " to go on ";
  di in w "3." in y
  "Unless we can see a distribution of estimates across samples it is " _n
  "difficult to demonstrate that the " in w "formulas " in y "for means and variances of" _n
  "OLS estimates reflect their " in w "true" in y " means and variances.  We can use the" _n
  "the computer to create " in w "many " in y "random samples from the " in w "same " in y "population" _n
  "and to OLS in each sample.  The result is a " in w "sample of estimates, " in y _n
  "one observation for each sample drawn from the population.  " _n;
  prompt " to go on ";
  di in w "4." in y
  "Using a computer to draw repeated samples from a populations using a random number " _n
  "generator is called the method of " in w "Monte Carlo. " in y "It is so named" _n
  "because roulette wheels and other gambling equipment are simply devices" _n
  "to draw many values from a population.  And Monte Carlo is known for gambling. " _n
  "Not coincidentally many early statistical results were derived from observing" _n
  "and then modeling results inside casinos." _n;
  prompt "when ready to go on";
  refresh;
  di in w "5. " in y
  "Step 3 of this tutorial allows you to run experiments on the" _n
  "linear regression model and OLS estimation of its parameters."_n
  "You can use step 3 to demonstrate the statistical" _n
  "properties of OLS that we have derived in class, because step 3" _n
  "will run repeated samples (replications) drawn from the same population"_n
  "regression function.  This allows you to " in w "directly " in y " observe aspects"  _n
  "of the OLS estimates such as: their means, variances, covariances"_n
  "and so forth.  Then you can compare, say, the " in w "actual " in y _n
  "variance of b2hat to the " in w "theoretically " in y "derived formulas."_n(2);
  prompt "to go on";
  di in w "6." in y
  "The ability to run Monte Carlo experiments gives you the ability to run" _n
  "EXPERIMENTS on the Regression Model and OLS estimates just like a " _n
  "physicist or a chemist would run an experiment.  That is, you can set " _n
  "the parameters of the experiment, run the experiment, and see the results." _n(2);
  prompt "to go on";
  di in w "7." in y
  "All the formulas we have derived can be demonstrated by Monte Carlo, so if " _n
  "doubt what the formula means, try to demonstrate it using the capabilities" _n
  "provided to you by Step 3." _n;
  di in w "8." in y
  "The remainder of this step provides an introduction to using step 3. Step 2 " _n
  "goes through an example of running step 3.";
  prompt "When ready to continue";
  refresh;
  di in b "9. What does Step 3 do?" _n(2) in y
     "Step 3 will ask you to specify EVERYTHING about a population" _n
     "regression and the samples drawn from it articifically using Stata." _n
     "For instance, before the experiment you will be asked to set:" _n
  in w "   N        sample size " _n
       "   sigma    the true (population) standard deviation of u " _n
       "   beta1    the true (population) constant term" _n
       "   beta2    the true (population) coefficient on X" _n
       "   R        the number of samples to draw (Replications of the experiment) ";
  di in y _n
     "Some things about the experiment are fixed.  For instance, in each" _n
     "experiment the values that X takes on are " in w "equally spaced " in y "within" _n
     "a specified range.  You will simply enter the UPPER" _n
     "and LOWER boundary of the range.  This lets you control the " _n
     "mean of X and the Sum of (X-meanX) squared in the population." _n(2);
  prompt "when ready to continue";
  refresh;
  di in w "10." in y
     "For example, if N=5, the LOWER bound on X = -1, and the UPPER bound = +1" _n
     "then in each artificial sample the 5 values of X in each sample will be "_n
     "equally spaced between -1 and 1: "  _n
in w "   X1=-1   X2=-0.5  X3=0    X4=0.5   X5=1       " _n(2) in b
     "                     Yaxis                   " _n
     "                     ^                      " _n
     "                     |                      " _n
     "                     |                      " _n
     "<----|-------|-------+--------|--------|----->X axis" _n
     "    -1      0.5     0.0      0.5       1        " _n
     "                     |                          " _n;
  prompt "to go on";
  di in w "11." in y
     "You also get to choose whether the disturbance terms are "_n
in w "normally distributed " in y "or not. To do this you will enter "_n
     "number between 0 and 1.  A value of " in w "0 " in y "means the " _n
     "u's are drawn from the normally distribution as in A.6.  A value of " _n
     in w " 1 " in y "means the u's"_n
     "are drawn from the uniform distribution (used in the week2 experiment)"_n
     "A value between 0 and 1, say 0.3, means that 70% of the u's" _n
     "terms will be normally distributed and 30% uniform." _n
     "Getting to choose whether A.6 is satisified lets you see whether the" _n
     "distribution of estimates are normally distributed or not if A.6 is"_n
     "not true.";
 prompt "when ready to continue";
 di in w "12." in y
    "Finally, you also can choose to have the results from one experiment" _n
    "to be added to the previous experiment.  You would do this so that " _n
    "you could compare the results when aspects of the sample change.  For " _n
    "instance, you can change the sample size or the mean of X and see the " _n
    "difference in the distribution of the estimates holding all other elments" _n
    "of the experiment constant.";
 di _n in w
 "Before running your own experiment, go to Step 2 to see an example";
end;

program define step14;
version 3.0;  set trace off;
quietly {;
       gen ttt = b2hat/se2;
       count if abs(ttt) < invt(13,0.95);
       macro define qa = _result(1);
       drop ttt;
       };
end;

program define step5;
version 3.0;  set trace off;
di in b
"          The Currently Loaded OLS Monte Carlo Experiment" _n
"          ------------------------------------------------" _n  in w
"Population Regression Function: " _n in b
"               Y    =     $true_b1     +     $true_b2 * X     +    u"  _n;
di in w "Summary of the PRF:" _n
"True beta1                  = " in b $true_b1 _col(40) in w
"True beta2                  = " in b $true_b2     _n in w
"Var(u)                      = " in b $sigma*$sigma _col(40) in w
"% of u's Uniformly Distr.   = "  in b 100*$umx "%" _n in w
"% of u's Normally Distr.    = "  in b 100*(1-$umx) "%" _n in w;
di in w "Summary of the Sample and the Experimental Design:" _n
"sample size (N)             = " in b $smp_size _col(40) in w
"replications (# of samples) = " in b $repl  _n in w
"Smallest X                  = "  in b $lowx _col(40) in w
"Largest X                   = "  in b $upx _n in w
"So in each artificial sample " _n in b
"       X1 = " %6.4f $xxx1 "     X2 = " %6.4f $xxx2 " ...    X$smp_size = " %6.4f $xxxn
		 _n in w
"Mean of X                   = " in b ($upx+$lowx)/2 _col(40) in w
"Sum of X**X                 = "  in b $sXisq  _n in w
"Sum of (X-meanX)*(X-meanX)  = "  in b $sxisq in w;
*"Correlation of u's          = "  in b $ucor _n;
end;

program define step12;
version 3.0; set trace off;
  set more 1;                           * turn off the more pause ;
  capture log close;                    * start a log file called monte.log ;
  cap log using monte, replace;
  log close;
  macro define sample = 1;              * sample is the loop counter ;
  local goon = "y";
  while $sample <= $repl {;             * do repl experiments;
	   quiet {;
	   clear;
	   set obs $smp_size;
	   gen x = round($lowx + (_n-1)*($upx-$lowx)/($smp_size-1),0.001);
	   gen yexp = $true_b1 + $true_b2*x;
	   gen mx = uniform();
	   gen nerr = $sigma*invnorm(uniform());
	   gen uerr = $sigma * sqrt(12) *(-0.5 + uniform());
	   gen rs = cond(mx>=$umx, nerr, uerr);
	   gen e = $ucor*rs[_n-1] + rs;
	   replace e = rs if _n==1;
	   gen y = yexp + e;                     * generate y ;
	   regress y x;                          * regress y on x ;
	   predict yhat;
	   if "`goon'" == "y" {;
	      if $logon==1 {;capture log using $zzln, append;};
	      inprompt "See sample $sample (y) or go on silently (n) (y/n)?";
	      local b1 = round(_b[_cons],0.01);
	      local b2 = round(_b[x],0.01);
	      local goon = "$junk";
	      if "`goon'" == "y"  {;
		 noisily {;
		 di in b
  "Population Regression Function: " _n in w
  "              Y    =     $true_b1   +   $true_b2 * X  +   u"  _n(2)
	       in b
  "Sample Regression Function in Sample #$sample" _n in w
  "              Y    =     `b1'    +    `b2'  * X   +    e " _n;
		 regress;
		 di _n in b
"Notice the difference between the OLS ESTIMATES and the population PARAMETERS." _n
		 "Press any key to see graph"; };
		 label var yexp "Popn: Y = $true_b1 + $true_b2 * X";
		 label var yhat "Sample: Y = `b1' + `b2' * X";
		 label var y    "Observed values of Y";
		 set more 0;
		 more;
		 graph y yhat yexp x, c(.ll) sort
		  title("Artificial Sample $sample");
		 set more 1;
		 cap log close;
		 };
	      else {;
		 noisily di in g
      "Rest of samples drawn automatically and results stored - be patient." _n
      "The total number of samples to be drawn = $repl" _n in r
      "Hit Ctrl-Break to stop the experiment" _n in w
      "The estimates being stored for each artificial sample are: " _n
      "        hat      hat      hat hat        hat       hat hat " _n
      "       sigma     b1       se (b1)        b2        se (b2) " };
		 cap log close;
		 cap log using monte, append;
		 log off;
		 };
	      };  * ends quiet ;

	   if "`goon'" == "y" {;cap log close; cap log using monte, append;};   *  write to the log file;
	   else {; cap log on;};
	   display $expno "  " in r $sample "  "  in y _result(9) "  " _b[_cons]
		   "  " _se[_cons] " " _b[x] " " _se[x];
	   if "`goon'" == "y" {;cap log close;};   *  write to the log file;
	   else               {; cap log off;};
	   quietly clear;
	   macro define sample = $sample+1;        * increment loop counter;
	   };                                      * ends the while loop;
       capture log close;
*
*  now monte reads the data it stored in monte.log and saves it to monte.dta
*   ;
   clear;
   infile expno sample sighat b1hat se1 b2hat se2 using monte.log;
   label data "Monte Carlo Results, N=$smp_size";
   label var expno "Experiment # (either 1 or 2)";
   label var sample "sample number";
   label var sighat " estimate of sigma";
   label var b1hat "estimate of true_b1";
   label var b2hat "estimate of true_b2";
   label var se1 "estimated standard error of b1hat";
   label var se2 "estimated standard error of b2hat";
   if "$app" == "y" | "$app" == "Y"
      {; cap append using mmm1; };
   else;
      {; cap save mmm1, replace; };
   di in b "The results of the experiment are now loaded";
   noisily beep; beep; beep;
   if $logon==1 {;
     capture log using $zzln, append;
     };
end;

program define step10;
  version 3.0; set trace off; cap capture;
  quietly {;
  macro define xxx1 = round($lowx,.001);
  macro define xxx2 = round($lowx + ($upx-$lowx)/($smp_size-1),.001);
  macro define xxxn = round($upx,.001);
  drop _all;
  set obs $smp_size;
  gen x = round($lowx + (_n-1)*($upx-$lowx)/($smp_size-1),0.001);
  egen sxsq = sum((x-($lowx+$upx)/2)*(x-($lowx+$upx)/2));
  egen sXsq = sum(x*x);
  macro define sxisq = round(sxsq[_N],0.001);
  macro define sXisq = round(sXsq[_N],0.001);
  drop _all;
  };
end;

program define step2;
 version 3.0; set trace off;
  di _col(10)
  in b
"Illustrate that OLS estimates are Unbiased under our Assumptions" _n(2);
  di in y
  "This step demonstrates how to use Step 3 to run a Monte Carlo Experiment" _n
  "First here is how you will enter the parameters (don't type anything " _n
  "this time, numbers will be entered for you): ";
  prompt "when ready";
 macro define true_b1 = 1.5;       * the true value of beta0;
 macro define true_b2 = -0.6;      * the true coefficient on x;
 macro define sigma = 3.0;         * the true st. dev. of the error term;
 macro define smp_size = 15;       * the sample size in each experiment;
 macro define repl = 80;           * the number of experiments to run;
 macro define lowx = -2.0;
 macro define upx = 2.0;
 macro define ucor = 0.0;
 macro define umx = 1.0;
 macro define app = "n";
 macro define expno = 1;
 set more 33;
 di in b
     "Enter TRUE " in w "b1" _cont; more; di in y " 1.5";
 di in b "Enter TRUE " in w "b2 " _cont; more; di in y " -0.6";
 di in b "Enter TRUE " in w "sigma" _cont; more; di in y " 3.0";
 di in b "Enter sample size " in w "N " _cont; more; di in y " 15";
 di in b "Enter number of artificial samples" _cont; more; di in y " 80";
 di in b "Enter LOWER bound of X values" _cont; more; di in y " -2.0";
 di in b "Enter UPPER bound of X values" _cont; more; di in y " 2.0";
 di in b "Enter % of u's to be NOT normally" _cont; more; di in y " 1.0";
 di in b "Append Results to a Previous experiment for comparison (y/n)?"
	   _cont; more; di in y " n" _n(2);
  set more 0;
  step10;
di "The program calculates the mean X, Sum X*X, and other non-random values" _n
   "for the experiment you have specified.";
di "Calling Step 5 at any time displays the parameters of the experiment:" _n;
  more;
  step5;
  more;
  di in y
  "The information above tells you all the details of the population and" _n
  "each sample except for the actual value of the random elements u.";
  di in w
  "Note that all the u's are drawn from the uniform distribution" _n
  "not the normal distribution.  That means that Assumption A.6 is " _n
  "violated.  We want to see if OLS is really unbiased under A.1 - A.5 alone";
  di _n in y
  "The following two questions require use of formulas given in lecture notes ";
  ansent "$sigma*$sigma/$sxisq" "What is the True Variance of b2hat?";
  di in b "Remember or write down the answer for reference later";
  prompt "when ready to go on";
  step5;
  ansent "$sigma*$sigma*$sXisq/($smp_size*$sxisq)"
	 "What is the True Variance of b1hat?";
  di in b "Remember or write down the answer for reference later";
  prompt  "When Ready to go on";
  refresh;
 di "Now the Monte Carlo experiment will be run on this population";
 prompt "when ready to run it";
 refresh;
 set seed 1111;                        * reset the random number generator;
 step12;
 prompt "When ready to look at the results of the experiment";
 refresh;
 step5;
 di in w "Output from Monte Carlo Experiment (Sample of Estimates):";
 describe;
 summ;
 di in y "The data are from $repl replications of OLS regression." _n
 "Notice the means st. dev. of the OLS estimates b1hat and" _n
 "b2hat.  How do they compare to the true mean and st. dev.?" _n(2)
 "Let's look at the histogram for b2hat across samples.  What do you" _n
 "think it will look like (remember A.6 is not satisfied in this population)?";
 prompt "When ready to look at the graph of b2hat.";
 graph b2hat, bin(12) xline($true_b2) freq l1(Number of samples)
	       title(Distribution of b2hat Across Samples);
 prompt "When ready to look at the graph of b1hat's.";
 graph b1hat, bin(12) xline($true_b1) freq l1(Number of samples)
	       title(Distribution of b1hat Across Samples);
 di in y "What do these graphs tell you about the estimates?" _n(2);
 prompt "when ready to continue";
 di in y "The data from the experiment will remain loaded for you to look at." _n
	 "And you can go on to Step 3 to run another experiment using different" _n
	 "population parameters.  " _n(2)
 "Use the experiment to verify that the formula for the estimated" _n
 "variance of b2hat is a good estimate of the actual variance" _n
 "of b2hat across artificial samples." _n;
 di in w
"Go to Step 4 for a list of questions you can answer using Monte Carlo.";
end;

program define step3;
  version 3.0;  set trace off;
  di _col(10)
  in y "See Steps 1 and 2 for explanation and example." _n;
  di in w "  First you need to set up the parameters of the experiment" _n;
  inprompt
  "Enter TRUE b1 to use (press ENTER to leave it equal to $true_b1)";
  capture confirm number $junk;
  if _rc == 0 {;  macro define true_b1 = $junk; };
  inprompt
  "Enter TRUE b2 term to use (press ENTER to leave equal to $true_b2)";
  capture confirm number $junk;
  if _rc == 0   {;  macro define true_b2 = $junk; };
  di "sigma is the square root of the variance of u";
  inprompt
  "Enter the TRUE sigma (press ENTER to leave equal to $sigma)";
  capture confirm number $junk;
  if _rc == 0   {;macro define sigma = $junk;};
  inprompt
  "Enter the sample size (press ENTER to leave equal to $smp_size)";
  capture confirm number $junk;
  if _rc == 0   {;macro define smp_size = $junk;};
  inprompt
  "Enter number of artificial samples (press ENTER to leave equal to $repl)";
  capture confirm number $junk;
  if _rc == 0   {; macro define repl = $junk;};
  inprompt "Enter LOWER bound of X values (press ENTER to leave it equal to $lowx)";
  capture confirm number $junk;
  if _rc == 0   {; macro define lowx = $junk; };
  inprompt "Enter UPPER bound of X values (press ENTER to leave equal to $upx)";
  capture confirm number $junk;
  if _rc == 0   {; macro define upx = $junk; };
  di
  "To satisfy Assumption A.6 enter 0 next or otherwise a number between 0 & 1";
  inprompt
  "Enter % of u's to be NOT normally (press ENTER to leave equal to $umx)";
  capture confirm number $junk;
  if _rc == 0  {; macro define umx = $junk; };
*  inprompt "Enter correlation between u's (-1 to 1, or -99 to leave the same)";
*  if $junk != -99 {; * macro define ucor = $junk; *};
  macro define ucor = 0;
  di "Enter y next if this is the second of two related experiments";
  inprompt "Append Results to a Previous experiment for comparison (y/n)?";
  capture confirm string $junk;
  if _rc == 0 {; macro define app = "$junk";
	       if "$app" == "y" | "$app" == "Y" {; macro define expno = 2; };
	       else {; macro define expno = 1; };
	       };
  else {; macro define expno = 1};
   step10;
   di in r "      You have specified the following Monte Carlo Experiment";
   step5;
  inprompt "Do you want to run it or not (y/n)?";
  if "$junk"=="y" {;step12; step5;};
  else {; di in r "Experiment not run - exiting step 3.";};
end;

program define step4;
  version 3.0;  set trace off;  cap preserve;
  di _col(10)
  in y "Here are some statements about OLS estimates.  They came from the" _n
       "definitions and formulas given in class.  You can design " _n
       "experiments that demonstrate them or other questions you have." _n in w
"         1. Under A.1-A.6 does the percentage of samples that contain the" _n
"            population parameter inside the confidence interval really equal" _n
"            to the confidence level?" _n
"            (You can confirm this for any population parameter: beta1, beta2" _n
"             Y|X, E(Y|X), etc.)" _n
"         2. Even when errors are not normally distributed (A.6 not true) are " _n
"            the confidence intervals approximately the proper size for the" _n
"            stated confidence level (1-alpha)?"_n;
di in w
"       * 3. With more variance in X is the variance in b2hat really smaller?" _n
"       * 4. With larger Sum of X**2 is the variance of b1hat really larger?" _n
"       * 5. Does the sign of the covariance of beta1hat and beta2hat really " _n
"            depends upon the sign of Xbar?" _n;
di in y
"The properties without a * can be illustrated with one experiment." _n
"The properties marked with a * can be illustrated by two" _n
"experiments where ONLY the property of interest changes" _n
"between the two experiments.  For instance, when increasing the" _n
"variance in X between experiments, you should change the parameters" _n
"in a way that leaves the mean of X the same.  You should answer yes " _n
"when asked to append the results of the second experiment to the first."_n;
end;

program define doquiz;
version 3.0;
refresh;
 di in r "          Quiz for Student Number " $id _n in b
"Unlike the previous quizzes, you can get " in w "credit " in b "for answering the question" _n
"correctly.  Correct answers will receive 15 homework marks (out " _n
"of approximately 530 possible this term).  No credit will be given to " _n
"incorrect answers. "_n(2)
"Answer should be e-mailed to Joanne by 12:00 PM, Tuesday, February 28." _n
"The correct answer DEPENDS upon your id number.";
prompt "when ready to start";
refresh;
 macro define true_b1 = 1.5;
 macro define true_b2 = -uniform()-0.1;
 macro define sigma = 2.0;
 macro define smp_size = 15;
 macro define repl = 50;
 macro define lowx = -2.0;
 macro define upx = 2.0;
 macro define ucor = 0.0;
 macro define umx = 0.0;
 macro define app = "n";
 macro define expno = 1;
 step10;
 di in w "First a Monte Carlo experiment must be run - be patient" _n
	 "The total number of samples to be drawn = $repl" _n in r
	 "Hit Ctrl-Break to stop the experiment" _n in w
	 "The computer will beep when its finished";
  set more 1;                           * turn off the more pause ;
  if $logon==1 {;
     di in r "Logging screen output will be suspended during the experiment";
     };
  capture log close;                    * start a log file called monte.log ;
  cap log using monte, replace;
  log off;
  macro define sample = 1;              * sample is the loop counter ;
  local goon = "y";
  while $sample <= $repl {;             * do repl experiments;
	   quiet {;
	   clear;
	   set obs $smp_size;
	   gen x = round($lowx + (_n-1)*($upx-$lowx)/($smp_size-1),0.001);
	   gen yexp = $true_b1 + $true_b2*x;
	   gen mx = uniform();
	   gen nerr = $sigma*invnorm(uniform());
	   gen uerr = $sigma * sqrt(12) *(-0.5 + uniform());
	   gen rs = cond(mx>=$umx, nerr, uerr);
	   gen e = $ucor*rs[_n-1] + rs;
	   replace e = rs if _n==1;
	   gen y = yexp + e;                     * generate y ;
	   regress y x;                          * regress y on x ;
	   predict yhat;
	   log on;
	   };
	   display $expno "  " $sample "  "  _result(9) "  " _b[_cons]
		   "  " _se[_cons] " " _b[x] " " _se[x];
	   log off;
	   quietly clear;
	   macro define sample = $sample+1;        * increment loop counter;
	   };                                      * ends the while loop;
   quietly {;
       capture log close;
       clear;
       infile expno sample sighat b1hat se1 b2hat se2 using monte.log;
       label data "Quiz Data, N=$smp_size, id=$id";
       label var expno "Experiment # (either 1 or 2)";
       label var sample "sample number";
       label var sighat " estimate of sigma";
       label var b1hat "estimate of true_b1";
       label var b2hat "estimate of true_b2";
       label var se1 "estimated standard error of b1hat";
       label var se2 "estimated standard error of b2hat";
       step14;
       };
   set more 0;
   beep; beep; beep;
   if $logon==1 {;
     capture log using $zzln, append;
     };
   di in w "The Monte Carlo Experiment just performed was:";
   step5;
   prompt "to see a summary of the experimental results";
   descr;
   summ;
   prompt "when ready to see the QUIZ question";
   di in y
  "Consider the following hypothesis about the Population Regression:" _n in w
  "              H0: b2=0 " _n
  "              HA: b2 not equal 0" _n
  "               alpha = 0.05";
  di _n in y
"We " in w "know " in y "H0 is FALSE because b2 = $true_b2 < 0.  But based on a sample " _n
"we might fail to reject H0.  As you know, the test statistic has a t " _n
"distribution under the null hypothesis.  You get a different number for " _n
"the test statistic in each artificial sample and reject H0 if |t| > t*." _n(2)
"Your job is to " in w "count " in y "the number of samples in which H0 is"
 in w " NOT REJECTED. " in y "Since "_n
 "the number of samples is $repl, your answer will be an integer between"_n
 "1 and $repl.  " _n(2)
 "In the body of your e-mail message, briefly interpret your answer. (Hint: " _n
 "think about Type I and Type II errors)";
  di _n in y
  "I'll save you some trouble and tell you that the critical value of t" _n
  "for alpha=0.05, two-tailed test, and sample size = $smp_size is t* = " invt(13,0.95);
  di _n in y
 "You may also find the " in w "count " in y "command to be helpful (type help count).";
  di _n in w
  "The data from the experiments remain loaded for you to use to complete the " _n
  "quiz.  You can go to Step 5 to see the experimental design again.";
end;
