#delimit ;

program define week7;
version 4.0;
if "`1'"=="" {;
   stepdef 1 "The F Distribution";
   stepdef 2 "Omitting a Variable in a Multiple Regression";
   stepdef 3 "F tests and t tests in Stata ";
  exit;
  };
 if "`1'"=="doquiz" {; doquiz; exit; };
 loc t = "step`1'"; `t';

end;

program define step9;
  version 3.0;
  drop _all;
  cap use city;
  cap use c:/stata/city;
  cap use c:/stustata/city;
  cap use d:/stustata/city;
  if _N < 109 {;
    refresh;
    di in r "I'm sorry.  I can't locate " in w "city.dta " in r "on this " _n
            "computer.  I've looked in the following directories: "
            _n _col(10) in w
            "c:/stata" _n _col(10)
            "c:/stustata" _n _col(10)
            "d:/stustata" _n _col(10);
    inprompt "enter the path to where the directory city.dta is located (eg. c:/mydata)";
    loc pth = "$junk"+"/city.dta";
    cap use `pth';
    if _N < 109 {; di in r "Still can't find it - exiting tutorial"; exit; };
    };
end;

program define step1;
 version 3.0; set trace off;
  di _col(10)
  in b
  "The F Distribution" _n(2);
  di in y
  "To perform tests of hypotheses on more than one regression coefficient"_n
  "at a time, we will use the " in w "F distribution. " _n
  in y "Here is its definition:";
  di in w _col(10)
     "If Z1 and Z2 are independently distributed chi-square random" _n _col(10)
     "variables with k1 and k2 degrees of freedom, then " _n _col(15)
     "          Z1 / k1   " _n _col(15)
     "   F  =   -------   " _n _col(15)
     "          Z2 / k2   " _n _col(10)
     "follows the F distribution with k1 and k2 degrees of freedom."_n;
  di in y
  "The F distribution is related to the t distribution.  " _n
  "Recall that the t distribution is a standard normal divided by the " _n
  "the square root of a chi-square divided by its degrees of freedom."  _n
  "And notice that if k1= 1 in the formula above, then Z1 is simply the " _n
  "square of a standard normal r.v. (by definition of a chi-square r.v.)." _n
  "The denominator of the F distribution has a chi-square divided " _n
  "by its degrees of freedom.  So if we square a t random variable, we get " _n
  "a F random variable with k1=1";
  di in w _col(15)
  " 2         " _n _col(15)
  "t   = F    " _n _col(15)
  " k     1,k " _n;
  prompt "when ready to go on";
  di in y
  "It is important to remember that the t distribution is not the same as" _n
  "the F distribution with 1 degree of freedom in its numerator.  Rather, " _n
  "the " in w "square " in y "of the t distribution is the same as F(1,k)." _n
  "This means that the F(1,k) statistic can be used to test any hypothesis " _n
  "that can be tested with the t distribution, but many tests can only be " _n
  "performed with the more general F(k1,k2) distribution.  This is why Stata's " _n
  in w " test " in y "command reports a F test.  An example is shown in step 3." _n
  "This does not mean you get the same test statistic or critical values when " _n
  "using the F or t test for the same hypothesis. Instead, you will get the same" _n
  "decisions (reject or fail to reject) based on either test.";
  prompt "When ready to go on";
  refresh;
  di in y "To perform hypotheses tests with the F distribution requires " _n
          "looking up critical values of the distribution, just as we did" _n
          "for tests based on the t-distribution.";
  di in y "You can use the" in w "fprob(df1,df2,f) " in y "function in Stata. ";
  prompt "when ready to go on";
  di 
   "Suppose you want to know the probability that the F statistic takes " _n
   "on a value greater than some critical value." _n
   "The fprob function will give you the answer to this " _n
   "question (probability that F is greater than some number).";
  set trace on;
  display fprob(1,22,1.40);
  set trace off;
  di in y "That is, " fprob(1,22,1.40) " is the probability that a F(1,22) " _n
        "random variable takes on a value greater than 1.40";
  prompt "when ready to go on";
  di "If you want to know the critical value for the F distribution " _n
     "given a significance level, use the " in w " invfprob " in y "function";
  set trace on;
  di in b "The critical value for alpha = .10 is " invfprob(3,10,0.10);
  di in b "To invert fprob: " invfprob(1,22,fprob(1,22,1.40));
  set trace off;
  di in y "Notice that in the second example we recovered the critical " _n
          "value 1.40 by inverting the fprob function ";
  refresh;
  di "Why does the F test end up in hypothesis tests?  Because we will be using" _n
     "the ratio of MSE's (mean squared errors) from two regressions.  Remember" _n
     "that the MSE divided by sigma, the true variance of disturbances u, and " _n
     "multiplied by degrees of freedom is chi-squared distributed.  So when " _n
     "using ratios of MSE we will be dealing with something that is F distributed.";
  di in b "Type next to go on to step 2";
end;

program define step2;
  version 3.0;  set trace off;  cap preserve;
  di in y "This step demonstrates the effect of leaving a variable" _n
     "out of a regression.  It will use the city.dta file used earlier." _n
     "We will demonstrate the results discussed on pages 178-182 in Gujarati.";
  prompt "enter when ready to go on";
  step9;
  di in y
  "The data is now loaded.  In week 4 we estimated the relation between" _n
  "poverty and crime rates.  Now let's consider the relation between some other"  _n
  "aspects of cities.  Let's first just consider the effect of region." _n
  "Cities in different parts of the U.S. are different. We'll keep it simple, " _n
  "and consider only the difference Southern and non-Southern cities" _n
  "by generating a dummy variable:";
  set trace on;
  tab region, summ(victims);
  gen south = cond(region==1,1,0);
  set trace off;
  sort south;
  prompt "when ready to see a graph";
  graph poor victims, by(south) ;
  di in y "The graph shows that crime victims rates, geography, and poverty" _n
          "are interrelated.";
  di in y "Here is the regression we ran earlier";
  prompt "when ready";
  set trace on;
  gen lvict = ln(victims);
  gen lpoor = ln(poor);
  regress lvict lpoor;
  macro define blpoor = _coef[lpoor];
  set trace off;
  di in y "The macro command stores the coefficient b2hat for later use." _n
   "Suppose that the true model is actually of the form" _n
   _col(15) in w "(**)   lvict = b1 + b2*lpoor + b3*south + u" _n(2)
   in y
   "If (**) is true we estimate the model without south in the regression" _n
   "it is as if we are imposing the constraint that b3hat = 0.  (We are NOT " _n
   "imposing the constraint that b3 = 0, because b3 is the TRUE parameter " _n
   "and we can't impose a value of it on the data.  The main question is" _n
   in b "How does b2hat change if we estimate b3hat?" _n;
   di in y
   "This question goes to the issue of how omitting important variables " _n
   "affects regression results.";
   prompt "when ready to see";
   set trace on;
   regress lvict lpoor south;
   macro define blpoor2 = _coef[lpoor];
   macro define bsouth = _coef[south];
   set trace off;
   di in y
   "The estimated coefficent on lpoor is now " _coef[lpoor] " whereas in " _n
   "the original regression the estimate was " $blpoor ". So the effect of " _n
   "poverty on crime rates appears to be lower when we take into account " _n
   "differences between Southern and non-Southern cities.  Souther cities " _n
   "appear to have more crime, holding poverty rates constant.  Why did the " _n
   "estimated coefficient change?";
   di in y
"Gujarati p. 179 shows that if we force b3hat = 0, we get a biased estimate " _n
"of b2.  In particular: " _n
in w _col(10) "(Guj 7.7.4)     E(b2hat) = b2 + b3 * v " _n
in y "where v is the coefficient on lpoor if we regress it on south. That is:";
set trace on;
regress south lpoor;
macro define vlpoor = _coef[lpoor];
set trace off;
di in y "For this sample, v = " _coef[lpoor] " and we see from the table that " _n
        "poor cities tend to be in the south.  Our estimate of b2hat went down " _n
        "when b3hat was estimated because the model was letting poverty explain" _n
        "some of the variation in crime rates that is really associated with " _n
        "geography.";
prompt "when ready to go on";
di in y "Here is a summary of what we've seen:  " _n
   "When we estimated"
   in w _n
   _col(10) "(*)  lvict  = b1hat + b2hat * lpoor + 0*south + e " _n
   in y "we found b2hat = " $blpoor _n
   "When we estimated "
   in w _n
   _col(10) "(**)  lvict  = b1hat + b2hat * lpoor + b3hat*south + e " _n
   in y " we found b2hat = " $blpoor2 " and b3hat = " $bsouth _n
   "When we estimated "
   in w _n
   _col(10) "(***)  south = v1hat + v2hat * lpoor + e " _n
   in y " we found v2hat = " $vlpoor _n(2)
   "and we can easily verify that "
   in w _n
   _col(10) $blpoor " = " $blpoor2 " + " $bsouth " * " $vlpoor _n(2)
   in y "which confirms Gujarati equation 7.7.4" _n;
prompt "when ready to go on";
refresh;
di in y "How does this relate to our assumptions about the regression model " _n
        "that guaranteed that OLS estimates are unbiased?  The short answer " _n
        "is that if (**) is the correct model, then forcing b3hat = 0 is not " _n
        "correct and A2 is violated.  But, we will almost never know " _n
        "what the true model is, so it might seem hopeless.  However, it is not " _n
        "because another way to look at this is to consider Assumption A3. " _n
 "In one form this assumes that the X's are not correlated with the u's." _n;
di in y "We can see that if poverty and region were unrelated, then v would be " _n
        "0 (or much closer to it than in this sample).  In that case, equation " _n
        "7.7.4 tells us that b2hat would be unbiased even if we force b3hat=0." _n
        "The reason is that forcing b3hat = 0 places all the effect of south " _n
        "on lvict into the disturbance term.  The estimate of b2hat then picks " _n
        "up the part of this effect that is correlated with lpoor." _n;
prompt "when ready to go on";
di in y "The moral is therefore:  the problem with not knowing the true model " _n
        "is NOT that important explanatory variables are left out of the model." _n
"That will almost always be true, and the disturbance term u is " _n
"actually designed to account for excluded variables.  " _n;
di "The problem is instead that: " _n
"important variables may be excluded that are related to the INCLUDED variables." _n
"This leads to a correlation between the X's and the u's which leads to " _n
"BIASED estimates of the regression coefficients.  In other words, omitted" _n
"variables only cause a problem with OLS estimates to the extent that they" _n
"are correlated with the INCLUDED X variables.  Correlation with the Y variable" _n
"is by itelf not enough to cause a problem";
prompt "when ready to go on";
refresh;
di in y
"A good exercise would be to confirm 7.7.4 for another set of variables " _n
"from one of the sample data sets.  ";
end;

program define step3;
  version 3.0;  set trace off;  cap preserve;
  di in y
  "In this step we use the same regression as in step 3 to demonstrate" _n
  "how to use the " in w "test "  in y "command and how t tests compare to F tests." _n;
  prompt "enter when ready to go on";
  step9;
  set trace on;
  tab region, summ(victims);
  gen south = cond(region==1,1,0);
  gen lvict = ln(victims);
  gen lpoor = ln(poor);
  regress lvict lpoor south;
  set trace off;
  di in y "Suppose that you wanted to test H0: b2 = 0.  The test would be "_n
          "exactly the same as in the simple regression case, except that the " _n
          "test statistic would now be t with N-3 degrees of freedom because " _n
          "three coefficients are estimated.  You can see from the t value in" _n
          "the table that you will reject H0 for typical levels of significance." _n
          "Notice the P(|t|>t) column next to the t column.  That equals the" _n
          "probability that a t statistic will take on a value greater than " _n
          "the computed t (absolute) value.  Using tprob to confirm this:";
  set trace on;
  di tprob(143,14.04);
  di tprob(143,3.352);
  set trace off;
  prompt "when ready to go on";
  refresh;
  regress;
  di in y "So suppose HA: b2 not equal 0 and alpha = 0.05.  Then you would reject "
          "H0 in this case, because 0.0 is less than 0.05.  In other words, the " _n
          "computed value of t is farther out in the tail of the t distribution " _n
          "than the critical value, which means you should reject H0." _n(2);

  prompt "when ready to go on";
  refresh;
  regress;
  di in y "Now notice what happens when I use test to test H0: ";
  set trace on;
  test lpoor;
  set trace off;
  di in y "Notice that P(F) = P(|t| >t ) = 0.00 in the table, and notice that " _n
          "196.95 = 14.04 * 14.04.  This indicates that test uses the F statistic " _n
          "to test the hypothesis, and the F value ends up being the square " _n
          "of the corresponding t value." _n
          "Notice that test can test other hypotheses: " ;
  prompt "when ready to go on";
  refresh;
  regress;
  set trace on;
  test lpoor = 1.0;
  set trace off;
  di in y
  "You should confirm that the F value for H0: b2=1.0 is the square " _n
  "of the t statistic for the same hypothesis that you already know how " _n
  "to compute.  Suppose that alternative is HA: b2 not equal 1.0 and suppose "_n
  "alpha = 0.05. Then" _n;
  ansent 1 "Should H0 be rejected (1) or fail to be rejected (0)?";
  test lpoor = 1.0;
  di in y "H0 should be rejected because the probability of F being" _n
          "bigger than the test statistic is LESS than 0.05.  That means the" _n
          "the test statistic is farther out in the tail than the critical value" _n
          "associated with alpha = 0.05.";
  prompt "when ready to go on";
  regress;
  set trace on;
  test lpoor = 1, notest;
  test _cons = -0.5, accum;
  set trace off;
  di in y "This is actually a test of two hypotheses simultaneously." _n
  "H0: b2 = 1 and b1 = -0.5.  The d.o.f. for the numerator of " _n
  "the F does not equal 1, so this statistic is not the square of the t" _n
  "statistic. We will be learning how to interpret such a test soon enough." _n
  "But you can tell by the probability value that H0 is soundly rejected by " _n
  "the data, even if you are not yet sure how to interpret H0.";
  prompt "when ready to conclude step 3";
  refresh;
  di in y
  "If you understand how " in w " test " in y "works, and how to use "_n
  "the probability values that it reports to carry out hypothesis tests, " _n
  "then go ahead and use it.  But don't take shortcuts unless you are absolutely " _n
  "sure you understand them.  If necessary write out all the mechanical aspects " _n
  "of a hypothesis test.";
  end;

